DROP TABLE medicar CASCADE CONSTRAINTS PURGE;
DROP TABLE consultar CASCADE CONSTRAINTS PURGE;
DROP TABLE remedio CASCADE CONSTRAINTS PURGE;
DROP TABLE telefone CASCADE CONSTRAINTS PURGE;
DROP TABLE acompanhante CASCADE CONSTRAINTS PURGE;
DROP TABLE medico CASCADE CONSTRAINTS PURGE;
DROP TABLE paciente CASCADE CONSTRAINTS PURGE;
DROP TABLE funcionario CASCADE CONSTRAINTS PURGE;
DROP TABLE enfermeiro CASCADE CONSTRAINTS PURGE;
DROP TABLE pessoa CASCADE CONSTRAINTS PURGE;
DROP TABLE hospital CASCADE CONSTRAINTS PURGE;


CREATE TABLE pessoa (
    nome varchar2(100) NOT NULL,
    idade integer,
    cep varchar2(9) NOT NULL,
    bairro varchar2(20) NOT NULL,
    descricao varchar2(20),
    sexo char(1) NOT NULL,
    cpf VARCHAR2(11),
    CONSTRAINT pk_pessoa PRIMARY KEY (cpf),
    CONSTRAINT pessoa_checkSex CHECK (sexo = 'M' OR sexo = 'F')
);

CREATE TABLE telefone (
  numero varchar2(30),
    cpf_pessoa varchar2(11),
    CONSTRAINT fk_Tel FOREIGN KEY (cpf_pessoa) REFERENCES pessoa(cpf),
    CONSTRAINT pk_Tel PRIMARY KEY (numero,cpf_pessoa) 
);

CREATE TABLE paciente (
  tipo_sanguineo varchar2(3) NOT NULL,
  cpf_pessoa varchar2(11),
  CONSTRAINT fk_paciente  FOREIGN KEY (cpf_pessoa) REFERENCES pessoa(cpf),
  CONSTRAINT pk_paciente PRIMARY KEY (cpf_pessoa),
  CONSTRAINT check_tipo_sanguineo CHECK (tipo_sanguineo='AB+' OR tipo_sanguineo='AB-' OR tipo_sanguineo='B+' OR tipo_sanguineo='B-' OR tipo_sanguineo='A+' OR tipo_sanguineo='A-' OR tipo_sanguineo='O+' OR tipo_sanguineo='O-')
);


CREATE TABLE funcionario(
  salario integer NOT NULL,
  cpf_pessoa varchar2(11),
  CONSTRAINT fk_funcionario FOREIGN KEY (cpf_pessoa) REFERENCES pessoa(cpf),
  CONSTRAINT pk_funcionario PRIMARY KEY (cpf_pessoa),
  CONSTRAINT check_salario CHECK (salario>879)
);

CREATE TABLE enfermeiro(
    registro_enf varchar2(10) NOT NULL,
    cpf_pessoa varchar2(11),
    CONSTRAINT fk_enfermeiro FOREIGN KEY (cpf_pessoa) REFERENCES pessoa(cpf),
    CONSTRAINT pk_enfermeiro PRIMARY KEY (cpf_pessoa)
);

CREATE TABLE acompanhante (
  nome varchar2(20) NOT NULL,
  horario_acompanhamento date,
  cpf_paciente varchar2(11),
  CONSTRAINT pk_acompanhante PRIMARY KEY(cpf_paciente, horario_acompanhamento),
  CONSTRAINT fk_acompanhante FOREIGN KEY(cpf_paciente) REFERENCES pessoa(CPF)
);

CREATE TABLE hospital (
    nome varchar2(20) NOT NULL,
    codigo varchar2(5),
    telefone_central_leitos varchar2(20),
    CONSTRAINT pk_hospital PRIMARY KEY (codigo)
);

CREATE TABLE medico(
  crm varchar2(14),
  urgencia integer,
  cpf_chefe varchar2(11),
  cpf_medico varchar2(11),
  CONSTRAINT pk_medico PRIMARY KEY(crm),
  CONSTRAINT fk_medico FOREIGN KEY(cpf_medico) REFERENCES funcionario(cpf_pessoa),
  CONSTRAINT fk_chefe FOREIGN KEY(cpf_chefe) REFERENCES funcionario(cpf_pessoa),
  CONSTRAINT check_urgencia CHECK (urgencia > 0 AND urgencia < 11)
);

CREATE TABLE remedio (
  nome varchar2(20) NOT NULL,
  num_serie varchar2(10),
  quantidade integer,
  marca varchar2(20) NOT NULL,
  prazo_validade date NOT NULL,
  substancia varchar2(20) NOT NULL,
  CONSTRAINT pk_remedio PRIMARY KEY(num_serie)
);

CREATE TABLE consultar (
  cpf_paciente varchar(50) NOT NULL,
  crm_medico varchar(14) NOT NULL,
  data date NOT NULL,
  codigo_hosp varchar2(5),
  CONSTRAINT pk_consultar PRIMARY KEY (data,cpf_paciente),
  CONSTRAINT fk_cmedico FOREIGN KEY (crm_medico) REFERENCES medico(crm),
  CONSTRAINT fk_cpaciente FOREIGN KEY (cpf_paciente) REFERENCES paciente(cpf_pessoa),
  CONSTRAINT fk_chospe FOREIGN KEY (codigo_hosp) REFERENCES hospital(codigo)
) ; 


CREATE TABLE medicar (
  cpf_paciente varchar(50) NOT NULL,
  cpf_enfermeiro varchar(50) NOT NULL,
  num_serie varchar(50) NOT NULL,
  data date NOT NULL,
  CONSTRAINT pk_medicar PRIMARY KEY(data,num_serie),
  CONSTRAINT fk_mpac FOREIGN KEY(cpf_paciente) REFERENCES paciente(cpf_pessoa),
  CONSTRAINT fk_menf FOREIGN KEY(cpf_enfermeiro) REFERENCES enfermeiro(cpf_pessoa),
  CONSTRAINT fk_mnse FOREIGN KEY(num_serie) REFERENCES remedio(num_serie)
) ;